@@ -34,7 +34,7 @@ class ChartBuilder:
         self._done = False
         self._last = None
         self._debug = debug
-        self._strict = True
+        self._strict = strict
         if self._builder:
             self._hypergraph = ph.Hypergraph()
             self._build = self._hypergraph.builder()
@@ -127,8 +127,8 @@ class ChartBuilder:
         return label in self._chart
 
     def __getitem__(self, label):
-        if self._strict:
-            raise Exception("Label not in chart: %s"%label)
+        if self._strict and label not in self._chart:
+            raise Exception("Label not in chart: %s"%(label,))
         if self._debug:
             print >>sys.stderr, "Getting", label, label in self._chart
         return self._chart.get(label, self._semiring.zero())
